require 'uu/os/rest/dto'
require 'uu/os/uesuri'

module UU

  module Finman

    module FinancialTransaction

      # DTO for create command of Transfer create.
      class TransferCreate < UU::OS::REST::DTO

        # Name of created Transfer. Required attribute. Cannot be null or empty.
        # @param [String]
        # @return [String]
        attr_accessor :name

        # Amount of the Transfer without vat. Required attribute. Cannot be null.
        # @param [Fixnum]
        # @return [Fixnum]
        attr_accessor :amount_without_vat

        # Amount of the Transfer with vat.
        # Either amount with vat or vat rate must be set.
        # @param [Fixnum]
        # @return [Fixnum]
        attr_accessor :amount_with_vat

        # UESURI of Contract.
        # @param [String, UU::OS::UESURI]
        # @return [UU::OS::UESURI]
        attr_accessor :contract_uri

        # Code of cost item.
        # @param [String]
        # @return [String]
        attr_accessor :cost_item_code

        # UESURI of the business case of non-control side of paynment.
        # Requrired attribute. Cannot be null.
        # @param [String, UU::OS::UESURI]
        # @return [UU::OS::UESURI]
        attr_accessor :counterparty_business_case_uri

        # Number of credit account.
        # Either number or UESURI of account must be set. Not both of them.
        # @param [String]
        # @return [String]
        attr_accessor :credit_account_number

        # UESURI of credit account artifact.
        # Either number or UESURI of account must be set. Not both of them.
        # @param [String, UU::OS::UESURI]
        # @return [UU::OS::UESURI]
        attr_accessor :credit_account_uri

        # Description for credit side.
        # @param [String]
        # @return [String]
        attr_accessor :credit_description

        # UESURI of credit financial category.
        # @param [String, UU::OS::UESURI]
        # @return [UU::OS::UESURI]
        attr_accessor :credit_financial_category_uri

        # Code of credit side currency.
        # @param [String]
        # @return [String]
        attr_accessor :credit_side_currency

        # Code of debit side currency.
        # @param [String]
        # @return [String]
        attr_accessor :debit_side_currency

        # Code of transaction currency.
        # @param [String]
        # @return [String]
        attr_accessor :transaction_currency

        # Credit vat date of the transaction.
        # @param [String, Time]
        # @return [String]
        attr_accessor :vat_date

        # Number of debit account.
        # Either number or UESURI of account must be set. Not both of them.
        # @param [String]
        # @return [String]
        attr_accessor :debit_account_number

        # UESURI of debit account artifact.
        # Either number or UESURI of account must be set. Not both of them.
        # @param [String, UU::OS::UESURI]
        # @return [UU::OS::UESURI]
        attr_accessor :debit_account_uri

        # Description for debit side.
        # @param [String]
        # @return [String]
        attr_accessor :debit_description

        # UESURI of debit financial category.
        # @param [String, UU::OS::UESURI]
        # @return [UU::OS::UESURI]
        attr_accessor :debit_financial_category_uri

        # Date the transfer is expected to be payed to.
        # Required attribute. Cannot be null.
        # @param [String, Time]
        # @return [String]
        attr_accessor :expected_pay_date

        # Type of financial transaction. Item from enumeration {UU::Finman::FinancialTransaction::FinancialTransactionType}.
        # Cannot be null. Following rules must be obeyed:
        #
        # If both UESURI of debit and credit account are set, then:
        # - if both accounts are Bank accounts, FinancialTransactionType.NONCASH must be set.
        # - if at least one account is Cash account, FinancialTransactionType.CASH must be set.
        # Otherwise any choice can be set.
        # @param [String, FinancialTransactionType]
        # @return [String]
        attr_accessor :financial_transaction_type

        # Code of income item.
        # @param [String]
        # @return [String]
        attr_accessor :income_item_code

        # Possible values: true or false. True indicates type of financial transaction as Credit, false as Debit.
        # If not set, default value is 'true'.
        # @param [TrueClass, FalseClass]
        # @return [TrueClass, FalseClass]
        attr_accessor :is_transaction_credit

        # Possible values: true or false. By setting to true the transfer will be automatically confirmed on the expected paydate.
        # If not set, default value is 'false'.
        # @param [TrueClass, FalseClass]
        # @return [TrueClass, FalseClass]
        attr_accessor :is_ready_to_be_paid

        # Original amount of the Transfer with vat.
        # @param [Fixnum]
        # @return [Fixnum]
        # @deprecated since 3-15-08. Not used any more. Value will be ignored.
        attr_accessor :original_amount_with_vat

        # Original currency code.
        # @param [String]
        # @return [String]
        # @deprecated since 3-15-08. Not used any more. Value will be ignored.
        attr_accessor :original_currency

        # Probability of transfer realization in %.
        # Required attribute. Cannot be null.
        # @param [Fixnum]
        # @return [Fixnum]
        attr_accessor :realization_probability

        # Vat rate.
        # Either amount with vat or vat rate must be set.
        # @param [Fixnum]
        # @return [Fixnum]
        attr_accessor :vat_rate

        # Dry run. If true, all validations will be processed, but transfer
        # will not be created.
        # @param [TrueClass, FalseClass]
        # @return [TrueClass, FalseClass]
        attr_accessor :dry_run

        def name
          attributes[:name]
        end

        def name=(val)
          attributes[:name] = val
        end

        def amount_without_vat
          attributes[:amountWithoutVat]
        end

        def amount_without_vat=(val)
          attributes[:amountWithoutVat] = val
        end

        def amount_with_vat
          attributes[:amountWithVat]
        end

        def amount_with_vat=(val)
          attributes[:amountWithVat] = val
        end

        def contract_uri
          attributes[:contractUri]
        end

        def contract_uri=(val)
          if val
            attributes[:contractUri] = UU::OS::UESURI.new(val)
          else
            attributes[:contractUri] = nil
          end
        end

        def cost_item_code
          attributes[:costItemCode]
        end

        def cost_item_code=(val)
          attributes[:costItemCode] = val
        end

        def counterparty_business_case_uri
          attributes[:counterpartyBusinessCaseUri]
        end

        def counterparty_business_case_uri=(val)
          if val
            attributes[:counterpartyBusinessCaseUri] = UU::OS::UESURI.new(val)
          else
            attributes[:counterpartyBusinessCaseUri] = nil
          end
        end

        def credit_account_number
          attributes[:creditAccountNumber]
        end

        def credit_account_number=(val)
          attributes[:creditAccountNumber] = val
        end

        def credit_account_uri
          attributes[:creditAccountUri]
        end

        def credit_account_uri=(val)
          if val
            attributes[:creditAccountUri] = UU::OS::UESURI.new(val)
          else
            attributes[:creditAccountUri] = nil
          end
        end

        def credit_description
          attributes[:creditDescription]
        end

        def credit_description=(val)
          attributes[:creditDescription] = val
        end

        def credit_financial_category_uri
          attributes[:creditFinancialCategoryUri]
        end

        def credit_financial_category_uri=(val)
          attributes[:creditFinancialCategoryUri] = val
        end

        def credit_side_currency
          attributes[:creditSideCurrency]
        end

        def credit_side_currency=(val)
          attributes[:creditSideCurrency] = val
        end

        def debit_side_currency
          attributes[:debitSideCurrency]
        end

        def debit_side_currency=(val)
          attributes[:debitSideCurrency] = val
        end


        def transaction_currency
          attributes[:transactionCurrency]
        end

        def transaction_currency=(val)
          attributes[:transactionCurrency] = val
        end

        def vat_date
          attributes[:vatDate]
        end

        def vat_date=(val)
          attributes[:vatDate] = val
        end

        def debit_account_number
          attributes[:debitAccountNumber]
        end

        def debit_account_number=(val)
          attributes[:debitAccountNumber] = val
        end

        def debit_account_uri
          attributes[:debitAccountUri]
        end

        def debit_account_uri=(val)
          if val
            attributes[:debitAccountUri] = UU::OS::UESURI.new(val)
          else
            attributes[:debitAccountUri] = nil
          end
        end

        def debit_description
          attributes[:debitDescription]
        end

        def debit_description=(val)
          attributes[:debitDescription] = val
        end

        def debit_financial_category_uri
          attributes[:debitFinancialCategoryUri]
        end

        def debit_financial_category_uri=(val)
          attributes[:debitFinancialCategoryUri] = val
        end

        def expected_pay_date
          attributes[:expectedPayDate]
        end

        def expected_pay_date=(val)
          attributes[:expectedPayDate] = val
        end

        def financial_transaction_type
          attributes[:financialTransactionType]
        end

        def financial_transaction_type=(val)
          attributes[:financialTransactionType] = val
        end

        def income_item_code
          attributes[:incomeItemCode]
        end

        def income_item_code=(val)
          attributes[:incomeItemCode] = val
        end

        def is_transaction_credit
          attributes[:isTransactionCredit]
        end

        def is_transaction_credit=(val)
          attributes[:isTransactionCredit] = val
        end

        def is_ready_to_be_paid
          attributes[:isReadyToBePaid]
        end

        def is_ready_to_be_paid=(val)
          attributes[:isReadyToBePaid] = val
        end

        def original_amount_with_vat
          attributes[:originalAmountWithVat]
        end

        def original_amount_with_vat=(val)
          attributes[:originalAmountWithVat] = val
        end

        def original_currency
          attributes[:originalCurrency]
        end

        def original_currency=(val)
          attributes[:originalCurrency] = val
        end

        def realization_probability
          attributes[:realizationProbability]
        end

        def realization_probability=(val)
          attributes[:realizationProbability] = val
        end

        def vat_rate
          attributes[:vatRate]
        end

        def vat_rate=(val)
          attributes[:vatRate] = val
        end

        def dry_run
          attributes[:dryRun]
        end

        def dry_run=(val)
          attributes[:dryRun] = val
        end
      end
    end
  end
end
